(function (Drupal, drupalSettings) {

  'use strict';

  document.addEventListener('DOMContentLoaded', function () {
      var utils = {
        extend: function (obj, src) {
          Object.keys(src).forEach(function (key) {
            obj[key] = src[key];
          });
          return obj;
        },
        hasClass: function (el, className) {
          return el.classList ? el.classList.contains(className) : new RegExp('\\b' + className + '\\b').test(el.className);
        },
        addClass: function (el, className) {
          if (el.classList) el.classList.add(className);
          else if (!hasClass(el, className)) el.className += ' ' + className;
        },
        removeClass: function (el, className) {
          if (el.classList) el.classList.remove(className);
          else el.className = el.className.replace(new RegExp('\\b' + className + '\\b', 'g'), '');
        },
        loadScript: function (url) {
          var script = document.createElement('script'),
            scripts = document.getElementsByTagName('script')[0];
          script.src = url;
          scripts.parentNode.insertBefore(script, scripts);
        }
      };

      var lazysizes = drupalSettings.lazy.lazysizes || {};

      if ('loading' in HTMLImageElement.prototype) {
        var element = document.querySelectorAll('[loading="lazy"]');
        element.forEach(function (el) {
          function loaded() {
            el.src = el.getAttribute(lazysizes.srcAttr);
            utils.removeClass(el, lazysizes.lazyClass);
            utils.addClass(el, lazysizes.loadedClass);

            // If parent element is a <picture> element, then there should be
            // <source> element(s) as well.
            var sources = el.parentNode.querySelectorAll('source');
            sources.forEach(function (source) {
              if (source.hasAttribute(lazysizes.srcsetAttr)) {
                source.srcset = source.getAttribute(lazysizes.srcsetAttr);
              }
              if (source.hasAttribute(lazysizes.sizesAttr)) {
                source.sizes = source.getAttribute(lazysizes.sizesAttr);
              }
            });
          }
          if (el.complete) {
            loaded()
          } else {
            el.addEventListener('load', loaded);
          }
        });
      } else {
        // 1. Lazysizes configuration.
        window.lazySizesConfig = window.lazySizesConfig || {};
        window.lazySizesConfig = utils.extend(window.lazySizesConfig, lazysizes);
        // 2. Load all selected lazysizes plugins.
        if (!Object.entries) {
          Object.entries = function(obj) {
            var ownProps = Object.keys(obj),
              i = ownProps.length,
              resArray = new Array(i);
            while (i--) {
              resArray[i] = [ownProps[i], obj[ownProps[i]]];
            }
            return resArray;
          };
        }
        Object.entries(lazysizes.plugins).forEach(function (path, key) {
          utils.loadScript(drupalSettings.path.baseUrl + 'libraries/lazysizes/plugins/' + path[1] + '.min.js');
        });
        // 3. Load the lazysizes library.
        utils.loadScript(drupalSettings.path.baseUrl + 'libraries/lazysizes/lazysizes.min.js');
      }
  });

})(Drupal, drupalSettings);
